#Temporal clustering of prey in wildlife passages provides no evidence of a prey‑trap
#Scientific Reports, 2020
#April Robin Martinig, Mahnoor Riaz, and Colleen Cassady St. Clair
#binomial distribution calculations
#Code for generating binomial distribution output for prey-predator sequences and prey-prey sequences
#This code was created by A. R. Martinig and last modified on June 26, 2020

#remove all objects
rm(list=ls(all=T))

#set working directory
setwd("~/Desktop/")

#loading all required packages
library(dplyr) #version 0.8.3
library(lubridate) #version 1.7.4

###########################################
#### treating squirrels (TAHU) as prey ####
####	             Table 1               ####	
###########################################

d1 = read.csv("raw data (clean).csv", header=TRUE) %>%
	mutate(pp=ifelse(sps %in% c("MUXX", "MUVI","VUVU"), 1,0)) #mutate to specify predators as 1 and prey as 0 #squirrels here treated as predators

d1$datetime=strftime(paste(d1$date,d1$time),'%Y-%m-%d %H:%M',usetz=FALSE) #converting the date/time into a new format  

#what is the actual latency b/w sequential events?
#trying to figure out how much time passes between observations (prey-prey, prey-predator, predator-predator, predator-prey)
d2 = d1 %>% 
	group_by(km, year) %>%
	arrange(datetime) %>%
	mutate(prev = dplyr::lead(pp), datetime=ymd_hm(datetime)) %>% 
	mutate(timedif = lead(datetime)-datetime) %>% #timedif is in seconds
	mutate(timedif=as.numeric(timedif)) #%>% #units get dropped by this

#timedif is originally in seconds #86400 seconds in 24 hours to convert to days
	
d2 = d2[2:nrow(d2),] %>% mutate(seque = as.factor(paste0(pp,prev))) %>%
	filter(seque %in% c("00", "01", "10", "11")) %>%
	ungroup() %>%
	mutate(seque = as.factor(seque))


stats_preyTAHU<-d2%>%
	group_by(km) %>% 
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	ka_prey_pred=sum(seque=="01"),
	ka_prey_prey=sum(seque=="00"),
	ka_pred_prey=sum(seque=="10"),
	ka_pred_pred=sum(seque=="11"),  
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	p0_prey_prey=((prey/total_pp)*(prey/total_pp)), # observed successes
	p0_pred_prey=((pred/total_pp)*(prey/total_pp)), # observed successes
	p0_pred_pred=((pred/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque, #ko value
	k0_prey_prey=p0_prey_prey*total_seque, #ko value
	k0_pred_prey=p0_pred_prey*total_seque, #ko value
	k0_pred_pred=p0_pred_pred*total_seque #ko value
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, ka_prey_pred, ka_prey_prey, ka_pred_prey, ka_pred_pred, p0_prey_pred, p0_prey_prey, p0_pred_prey, p0_pred_pred, k0_prey_pred, k0_prey_prey, k0_pred_prey, k0_pred_pred)

#is our result significantly different than random?
output_TAHUprey <- t(`colnames<-`(apply(stats_preyTAHU, 1, function(x) {
  bin1 <- binom.test(x[6], x[3], x[10], "two.sided")
  bin2 <- binom.test(x[7], x[3], x[11], "two.sided")
  bin3 <- binom.test(x[8], x[3], x[12], "two.sided")
  out_prey_pred<-with(bin1, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1], "97.5%_prey_pred"=conf.int[2]))
  out_prey_prey <-with(bin2, c(pa_prey_prey =unname(estimate), pvalue_prey_prey=unname(p.value), "2.5%_prey_prey"=conf.int[1],  "97.5%_prey_prey"=conf.int[2]))
  out_pred_prey <-with(bin3, c(pa_pred_prey=unname(estimate), pvalue_pred_prey=unname(p.value), "2.5%_pred_prey"=conf.int[1], "97.5%_pred_prey"=conf.int[2]))
  c(x, out_prey_pred, out_prey_prey, out_pred_prey)
}), stats_preyTAHU$km))

output_TAHUprey

overall<-d2%>%
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	prey_pred=sum(seque=="01"),
	prey_prey=sum(seque=="00"),
	pred_prey=sum(seque=="10"), 
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	p0_prey_prey=((prey/total_pp)*(prey/total_pp)), # observed successes
	p0_pred_prey=((pred/total_pp)*(prey/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque, #ko value
	k0_prey_prey=p0_prey_prey*total_seque, #ko value
	k0_pred_prey=p0_pred_prey*total_seque, #ko value
	) %>% 
	group_by(km) %>%
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, prey_pred, prey_prey, pred_prey, p0_prey_pred, p0_prey_prey, p0_pred_prey, k0_prey_pred, k0_prey_prey, k0_pred_prey)


#is our result significantly different than random?
output_overall <- t(`colnames<-`(apply(overall, 1, function(x) {
  bin1 <- binom.test(x[6], x[3], x[9], "two.sided")
  bin2 <- binom.test(x[7], x[3], x[10], "two.sided")
  bin3 <- binom.test(x[8], x[3], x[11], "two.sided")
  out_prey_pred<-with(bin1, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1], "97.5%_prey_pred"=conf.int[2]))
  out_prey_prey <-with(bin2, c(pa_prey_prey =unname(estimate), pvalue_prey_prey=unname(p.value), "2.5%_prey_prey"=conf.int[1],  "97.5%_prey_prey"=conf.int[2]))
  out_pred_prey <-with(bin3, c(pa_pred_prey=unname(estimate), pvalue_pred_prey=unname(p.value), "2.5%_pred_prey"=conf.int[1], "97.5%_pred_prey"=conf.int[2]))
  c(x, out_prey_pred, out_prey_prey, out_pred_prey)
}), overall$km))

head(output_overall, 1)






#########################
#### TAHU = EXCLUDED ####
####  	 Table S1    ####
#########################

noTAHU = read.csv("raw data (clean).csv", header=TRUE) %>%
	filter(!sps %in% c("TAHU")) %>%  #deletes squirrels from observations
	mutate(pp=ifelse(sps %in% c("MUXX", "MUVI","VUVU"), 1,0))#mutate to specify predators as 1 and prey as 0 #squirrels here treated as predators

noTAHU$datetime=strftime(paste(noTAHU $date, noTAHU $time),'%Y-%m-%d %H:%M',usetz=FALSE) #converting the date/time into a new format  

#what is the actual latency b/w sequential events?
#trying to figure out how much time passes between observations (prey-prey, prey-predator, predator-predator, predator-prey)
noTAHU2 = noTAHU %>% 
	ungroup() %>% 
	group_by(km, year) %>%
	arrange(datetime) %>%
	mutate(prev = dplyr::lead(pp), datetime=ymd_hm(datetime)) %>% 
	mutate(timedif = lead(datetime)-datetime) %>% #timedif is in seconds
	mutate(timedif=as.numeric(timedif)) #%>% #units get dropped by this

#timedif is originally in seconds #86400 seconds in 24 hours to convert to days
	
noTAHU2 = noTAHU2[2:nrow(noTAHU2),] %>% mutate(seque = as.factor(paste0(pp,prev))) %>%
	filter(seque %in% c("00", "01", "10", "11")) %>%
	ungroup() %>%
	mutate(seque = as.factor(seque))



#to get percent per passage
stats_noTAHU<-noTAHU2%>%
	group_by(km) %>% 
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	ka_prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque #ko value
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, ka_prey_pred, p0_prey_pred, k0_prey_pred)

#is our result significantly different than random?
output_prey_pred_noTAHU <- t(`colnames<-`(apply(stats_noTAHU, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), stats_noTAHU$km))

output_prey_pred_noTAHU


overall_noTAHU<-noTAHU2%>%
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, prey_pred,p0_prey_pred,k0_prey_pred)

#is our result significantly different than random?
output_overall_noTAHU <- t(`colnames<-`(apply(overall_noTAHU, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), overall_noTAHU $km))
head(output_overall_noTAHU, 1)





#########################
#### TAHU = PREDATOR ####
####  	 Table S2    ####
#########################

predTAHU = read.csv("raw data (clean).csv", header=TRUE) %>%
	mutate(pp=ifelse(sps %in% c("MUXX", "MUVI","VUVU", "TAHU"), 1,0)) #mutate to specify predators as 1 and prey as 0 #squirrels here treated as predators

predTAHU $datetime=strftime(paste(predTAHU $date, predTAHU $time),'%Y-%m-%d %H:%M',usetz=FALSE) #converting the date/time into a new format  

#what is the actual latency b/w sequential events?
#trying to figure out how much time passes between observations (prey-prey, prey-predator, predator-predator, predator-prey)
predTAHU2 = predTAHU %>% 
	ungroup() %>% 
	group_by(km, year) %>%
	arrange(datetime) %>%
	mutate(prev = dplyr::lead(pp), datetime=ymd_hm(datetime)) %>% 
	mutate(timedif = lead(datetime)-datetime) %>% #timedif is in seconds
	mutate(timedif=as.numeric(timedif)) #%>% #units get dropped by this

#timedif is originally in seconds #86400 seconds in 24 hours to convert to days
	
predTAHU2 = predTAHU2[2:nrow(predTAHU2),] %>% mutate(seque = as.factor(paste0(pp,prev))) %>%
	filter(seque %in% c("00", "01", "10", "11")) %>%
	ungroup() %>%
	mutate(seque = as.factor(seque))



#to get percent per passage
stats_predTAHU<-predTAHU2%>%
	group_by(km) %>% 
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	ka_prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque #ko value
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, ka_prey_pred, p0_prey_pred, k0_prey_pred)


#is our result significantly different than random?
output_prey_pred_predTAHU <- t(`colnames<-`(apply(stats_predTAHU, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), stats_predTAHU$km))

output_prey_pred_predTAHU

overall_predTAHU<-predTAHU2%>%
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, prey_pred,p0_prey_pred,k0_prey_pred)

#is our result significantly different than random?
output_overall_predTAHU <- t(`colnames<-`(apply(overall_predTAHU, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), overall_predTAHU $km))
head(output_overall_predTAHU, 1)






###########################
#### 2012, TAHU = PREY ####
####     Table S4      ####
###########################

only2012 = read.csv("raw data (clean).csv", header=TRUE) %>%
	mutate(pp=ifelse(sps %in% c("MUXX", "MUVI","VUVU"), 1,0)) %>% #mutate to specify predators as 1 and prey as 0 #squirrels here treated as predators
	filter(year=="2012") #restrict data to specific year

only2012 $datetime=strftime(paste(only2012 $date, only2012 $time),'%Y-%m-%d %H:%M',usetz=FALSE) #converting the date/time into a new format  

#what is the actual latency b/w sequential events?
#trying to figure out how much time passes between observations (prey-prey, prey-predator, predator-predator, predator-prey)
only2012_2 = only2012 %>% 
	ungroup() %>% 
	group_by(km, year) %>%
	arrange(datetime) %>%
	mutate(prev = dplyr::lead(pp), datetime=ymd_hm(datetime)) %>% 
	mutate(timedif = lead(datetime)-datetime) %>% #timedif is in seconds
	mutate(timedif=as.numeric(timedif)) #%>% #units get dropped by this

#timedif is originally in seconds #86400 seconds in 24 hours to convert to days
	
only2012_2 = only2012_2[2:nrow(only2012_2),] %>% mutate(seque = as.factor(paste0(pp,prev))) %>%
	filter(seque %in% c("00", "01", "10", "11")) %>%
	ungroup() %>%
	mutate(seque = as.factor(seque))


stats_preyTAHU2012<-only2012_2%>%
	group_by(km) %>% 
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	ka_prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, ka_prey_pred, p0_prey_pred, k0_prey_pred)

#is our result significantly different than random?
output_TAHUprey2012 <- t(`colnames<-`(apply(stats_preyTAHU2012, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), stats_preyTAHU2012 $km))

output_TAHUprey2012


overall_2012<-only2012_2%>%
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes	
	k0_prey_pred=p0_prey_pred*total_seque #ko
	) %>% 
	group_by(km) %>%
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, prey_pred, p0_prey_pred, k0_prey_pred)


#is our result significantly different than random?
overall_2012_TAHUprey <- t(`colnames<-`(apply(overall_2012, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), overall_2012 $km))
 
head(overall_2012_TAHUprey, 1)



###########################
#### 2015, TAHU = PREY ####
####     Table S5      ####
###########################

only2015 = read.csv("raw data (clean).csv", header=TRUE) %>%
	mutate(pp=ifelse(sps %in% c("MUXX", "MUVI","VUVU"), 1,0)) %>% #mutate to specify predators as 1 and prey as 0 #squirrels here treated as predators
	filter(year=="2015") #restrict data to specific year

only2015 $datetime=strftime(paste(only2015 $date, only2015 $time),'%Y-%m-%d %H:%M',usetz=FALSE) #converting the date/time into a new format  

#what is the actual latency b/w sequential events?
#trying to figure out how much time passes between observations (prey-prey, prey-predator, predator-predator, predator-prey)
only2015_2 = only2015 %>% 
	ungroup() %>% 
	group_by(km, year) %>%
	arrange(datetime) %>%
	mutate(prev = dplyr::lead(pp), datetime=ymd_hm(datetime)) %>% 
	mutate(timedif = lead(datetime)-datetime) %>% #timedif is in seconds
	mutate(timedif=as.numeric(timedif)) #%>% #units get dropped by this

#timedif is originally in seconds #86400 seconds in 24 hours to convert to days
	
only2015_2 = only2015_2[2:nrow(only2015_2),] %>% mutate(seque = as.factor(paste0(pp,prev))) %>%
	filter(seque %in% c("00", "01", "10", "11")) %>%
	ungroup() %>%
	mutate(seque = as.factor(seque))


stats_preyTAHU2015<-only2015_2%>%
	group_by(km) %>% 
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	ka_prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, ka_prey_pred, p0_prey_pred, k0_prey_pred)

#is our result significantly different than random?
output_TAHUprey2015 <- t(`colnames<-`(apply(stats_preyTAHU2015, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), stats_preyTAHU2015 $km))

output_TAHUprey2015


overall_2015<-only2015_2%>%
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes	
	k0_prey_pred=p0_prey_pred*total_seque #ko
	) %>% 
	group_by(km) %>%
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, prey_pred, p0_prey_pred, k0_prey_pred)


#is our result significantly different than random?
overall_2015_TAHUprey <- t(`colnames<-`(apply(overall_2015, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), overall_2015 $km))
 
head(overall_2015_TAHUprey, 1)




#############################
#### august, TAHU = PREY ####
#####     Table S5      #####
#############################

august = read.csv("raw data (clean).csv", header=TRUE) %>%
	mutate(pp=ifelse(sps %in% c("MUXX", "MUVI","VUVU"), 1,0)) %>% #mutate to specify predators as 1 and prey as 0 #squirrels here treated as predators
	filter(month %in% c("august")) #restrict data to specific month

august $datetime=strftime(paste(august $date, august $time),'%Y-%m-%d %H:%M',usetz=FALSE) #converting the date/time into a new format  

#what is the actual latency b/w sequential events?
#trying to figure out how much time passes between observations (prey-prey, prey-predator, predator-predator, predator-prey)
august2 = august %>% 
	ungroup() %>% 
	group_by(km, year) %>%
	arrange(datetime) %>%
	mutate(prev = dplyr::lead(pp), datetime=ymd_hm(datetime)) %>% 
	mutate(timedif = lead(datetime)-datetime) %>% #timedif is in seconds
	mutate(timedif=as.numeric(timedif)) #%>% #units get dropped by this

#timedif is originally in seconds #86400 seconds in 24 hours to convert to days
	
august2 = august2[2:nrow(august2),] %>% mutate(seque = as.factor(paste0(pp,prev))) %>%
	filter(seque %in% c("00", "01", "10", "11")) %>%
	ungroup() %>%
	mutate(seque = as.factor(seque))


stats_preyTAHUaug<-august2%>%
	group_by(km) %>% 
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	ka_prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes
	k0_prey_pred=p0_prey_pred*total_seque
	) %>% 
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, ka_prey_pred, p0_prey_pred, k0_prey_pred)

#is our result significantly different than random?
output_TAHUpreyaug <- t(`colnames<-`(apply(stats_preyTAHUaug, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), stats_preyTAHUaug $km))

output_TAHUpreyaug	

overall_aug<-august2%>%
	mutate(total_pp=n(), # sample size
	total_seque=n()-1, # sample size - 1 (i.e. number of sequences)
	prey=sum(pp==0),
	pred=sum(pp==1),
	prey_pred=sum(seque=="01"),
	p0_prey_pred=((prey/total_pp)*(pred/total_pp)), # observed successes	
	k0_prey_pred=p0_prey_pred*total_seque #ko
	) %>% 
	group_by(km) %>%
	filter(row_number()==n()) %>% 
	arrange(km) %>%
	select(km, n=total_pp, n_1=total_seque, prey, pred, prey_pred, p0_prey_pred, k0_prey_pred)


#is our result significantly different than random?
overall_aug_TAHUprey <- t(`colnames<-`(apply(overall_aug, 1, function(x) {
  rr <- binom.test(x[6], x[3], x[7], "two.sided")
  with(rr, c(x,  pa_prey_pred =unname(estimate), pvalue_prey_pred=unname(p.value), "2.5%_prey_pred"=conf.int[1],
             "97.5%_prey_pred"=conf.int[2]))
}), overall_aug $km))
 
head(overall_aug_TAHUprey, 1)
