#Temporal clustering of prey in wildlife passages provides no evidence of a prey‑trap
#Scientific Reports, 2020
#April Robin Martinig, Mahnoor Riaz, and Colleen Cassady St. Clair
#latencies between visits by predators and prey at 17 wildlife passages in the Laurentides Wildlife Reserve
#Code for generating output in Table 2 
#This code was created by A. R. Martinig and last modified on June 26, 2020

#remove all objects
rm(list=ls(all=T))

#set working directory
setwd("~/Desktop/")

#loading all required packages
library(dplyr) #version 0.8.3
library(glmmTMB) #version 1.0.1
library(psych) #version 1.9.12.31
library(lsmeans) #version 2.30-0

#import data
latencies = read.csv("all latencies (clean).csv", header=T) 

#summary statistics for latency between sequences

geo = latencies %>% group_by(seque, km) %>% summarise(geometric.mean(timedif_hours))
geo

#the average geometric mean time difference for all passages for each sequence 
x<-aggregate(`geometric.mean(timedif_hours)`~seque, data=geo, mean)
x
y<-aggregate(`geometric.mean(timedif_hours)`~seque, data=geo, FSA::se)
y


##########################################
###         LATENCY RESULTS            ###
### all sequences with latency in days ###
##########################################

#set reference levels for data
latencies$type<-relevel(latencies$type, ref="DCC")
latencies$seque=factor(latencies$seque, levels = c("py-py", "py-pd", "pd-py", "pd-pd"))

summary(latencies)
head(latencies)

latency= glmmTMB(timedif_days ~ seque + type + openness +year_std + month + (1|culv.id), family=nbinom2, data = latencies)

#to extract estimates and CIs from pairwise comparisons

#extract values for sequences
lsmeans(latency, pairwise~seque)
confint((lsmeans(latency, pairwise~seque)),method='wald')

#extract values for wildlife passage types
lsmeans(latency, pairwise~type)
confint((lsmeans(latency, pairwise~type)),method='wald')

#extract values for openness, year, and month (august compared to rest)
summary(latency)
confint(latency,method='wald')



####################################
#####     LATENCY RESULTS      #####
#####  only sequences <=1 day  #####
#####     latency in hours     #####
####################################

latencies2<-latencies %>%
	dplyr::filter(timedif_hours <= 24) #restict to <=24 hours 
	
latency2= glmmTMB(timedif_hours ~ seque + type + openness + year_std + month + (1|culv.id), family=nbinom2, data = latencies2)

#to extract estimates and CIs from pairwise comparisons

#extract values for sequences
lsmeans(latency2, pairwise~seque)
confint((lsmeans(latency2, pairwise~seque)),method='wald')

#extract values for wildlife passage types
lsmeans(latency2, pairwise~type)
confint((lsmeans(latency2, pairwise~type)),method='wald')

#extract values for openness, year, and month (august compared to rest)
summary(latency2)
confint(latency2,method='wald')